summaryrefslogtreecommitdiffstats
path: root/noatun-plugins/oblique/tree.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit90363652674deb94cd07057428b24fcb1735dbce (patch)
tree35013223cb731f194f8584cc1c06a023c3c75c85 /noatun-plugins/oblique/tree.cpp
parent627b091fad9df13695f249588e8a58f524eda0fa (diff)
downloadtdeaddons-90363652674deb94cd07057428b24fcb1735dbce.tar.gz
tdeaddons-90363652674deb94cd07057428b24fcb1735dbce.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeaddons@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'noatun-plugins/oblique/tree.cpp')
-rw-r--r--noatun-plugins/oblique/tree.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/noatun-plugins/oblique/tree.cpp b/noatun-plugins/oblique/tree.cpp
index fdf210e..7f3415c 100644
--- a/noatun-plugins/oblique/tree.cpp
+++ b/noatun-plugins/oblique/tree.cpp
@@ -76,7 +76,7 @@ static void treeItemSort(TreeItem **begin, TreeItem **end)
static void treeItemSort(TreeItem *first)
{
- const int count = first->tqparent() ? first->tqparent()->childCount() : first->listView()->childCount();
+ const int count = first->parent() ? first->parent()->childCount() : first->listView()->childCount();
if (count < 2) return;
Query *q = first->tree()->query();
@@ -149,28 +149,28 @@ inline static void sortify(T *item)
}
-TreeItem::TreeItem(Tree *tqparent, QueryGroup *group, const File &file, const TQString &p)
- : KListViewItem(tqparent, p), mGroup(group), mUserOpened(false), mHidden(false)
+TreeItem::TreeItem(Tree *parent, QueryGroup *group, const File &file, const TQString &p)
+ : KListViewItem(parent, p), mGroup(group), mUserOpened(false), mHidden(false)
{
if (group->option(QueryGroup::Playable))
{
if (mFile = file)
- tqparent->mPlayableItemCount++;
+ parent->mPlayableItemCount++;
}
- sortify(tqparent);
+ sortify(parent);
}
-TreeItem::TreeItem(TreeItem *tqparent, QueryGroup *group, const File &file, const TQString &p)
- : KListViewItem(tqparent, p), mGroup(group), mUserOpened(false), mHidden(false)
+TreeItem::TreeItem(TreeItem *parent, QueryGroup *group, const File &file, const TQString &p)
+ : KListViewItem(parent, p), mGroup(group), mUserOpened(false), mHidden(false)
{
if (group->option(QueryGroup::Playable))
{
if (mFile = file)
- tqparent->tree()->mPlayableItemCount++;
+ parent->tree()->mPlayableItemCount++;
}
- sortify(tqparent);
+ sortify(parent);
}
TreeItem::~TreeItem()
@@ -180,7 +180,7 @@ TreeItem::~TreeItem()
tree()->mPlayableItemCount--;
}
// I have to remove my tqchildren, because they need their tqparent
// in tact for the below code
while (TreeItem *c = firstChild())
delete c;
@@ -297,7 +297,7 @@ void TreeItem::paintCell(TQPainter *p, const TQColorGroup &cg, int column, int w
}
TQColorGroup newcg(cg);
- if (tqparent() && tqparent()->isOpen() && !tqparent()->mUserOpened)
+ if (parent() && parent()->isOpen() && !parent()->mUserOpened)
{
// slow, but not often used
TQColor text = newcg.text();
@@ -338,8 +338,8 @@ void TreeItem::autoExpand()
void TreeItem::forceAutoExpand()
{
- if (tqparent())
- tqparent()->forceAutoExpand();
+ if (parent())
+ parent()->forceAutoExpand();
if (!mUserOpened)
tree()->addAutoExpanded(this);
@@ -419,7 +419,7 @@ TreeItem *TreeItem::next()
{
if (upYours->nextSibling())
return upYours->nextSibling();
- upYours = upYours->tqparent();
+ upYours = upYours->parent();
} while (upYours);
}
return 0;
@@ -431,8 +431,8 @@ TreeItem *TreeItem::next()
-Tree::Tree(Oblique *oblique, TQWidget *tqparent)
- : KListView(tqparent), mOblique(oblique), mAutoExpanding(0)
+Tree::Tree(Oblique *oblique, TQWidget *parent)
+ : KListView(parent), mOblique(oblique), mAutoExpanding(0)
{
mCurrent = 0;
lastMenu =0;
@@ -503,16 +503,16 @@ void Tree::clear()
KListView::clear();
}
-void Tree::movableDropEvent (TQListViewItem* tqparent, TQListViewItem* afterme)
+void Tree::movableDropEvent (TQListViewItem* parent, TQListViewItem* afterme)
{
TQPtrList<TQListViewItem> items = selectedItems(true);
for (TQPtrList<TQListViewItem>::Iterator i(items.begin()); *i; ++i)
{
- if ((*i)->tqparent() != tqparent)
+ if ((*i)->parent() != parent)
return;
}
- KListView::movableDropEvent(tqparent, afterme);
+ KListView::movableDropEvent(parent, afterme);
}
@@ -790,7 +790,7 @@ TreeItem *Tree::node(TreeItem *fix, QueryGroup *group, const File &file, TreeIte
else if (fix)
{
item = fix;
- if (fix->tqparent() != childOf)
+ if (fix->parent() != childOf)
moveItem(fix, childOf, 0);
item->setText(0, presentation);
}
@@ -180,7 +180,7 @@ TreeItem::~TreeItem()
tree()->mPlayableItemCount--;
}
- // I have to remove my tqchildren, because they need their tqparent
+ // I have to remove my tqchildren, because they need their parent
// in tact for the below code
while (TreeItem *c = firstChild())